#![allow(unused)]

mod cli;
mod scripts;

use anyhow::Result;
use clap::Parser;

fn main() -> Result<()> {
    // always load dotenv on start
    dotenvy::dotenv().ok();

    let args = cli::Ahab::parse();

    match args.command {
        cli::Commands::D { command } => match command {
            cli::Docker::StopAll => scripts::docker::stop_all(),
        },
        cli::Commands::Dc { command } => match command {
            cli::DockerCompose::Build => scripts::docker_compose::build(),
            cli::DockerCompose::Down => scripts::docker_compose::down(),
            cli::DockerCompose::Rebuild => scripts::docker_compose::rebuild(),
            cli::DockerCompose::Restart => scripts::docker_compose::restart(),
            cli::DockerCompose::Start => scripts::docker_compose::start(),
            cli::DockerCompose::Stop => scripts::docker_compose::stop(),
            cli::DockerCompose::Up => scripts::docker_compose::up(),
        },
        cli::Commands::Dj { command } => match command {
            cli::Django::MakeCommand { app, command } => {
                scripts::django::make_command(&app, &command)
            }
            cli::Django::Makemigrations => scripts::django::makemigrations(),
            cli::Django::Manage { rest } => scripts::django::manage(&rest),
            cli::Django::Migrate => scripts::django::migrate(),
            cli::Django::Shell => scripts::django::shell(),
        },
        cli::Commands::Pg { command } => match command {
            cli::Postgres::Import { path } => scripts::postgres::import(&path),
            cli::Postgres::Dump { path } => scripts::postgres::dump(&path),
        },
    }
}
