pub mod django;
pub mod docker;
pub mod docker_compose;
pub mod postgres;

use std::{ffi::OsStr, process::Command};

use anyhow::{Context, Result};

struct DockerCommand {
    command: Command,
}

impl DockerCommand {
    fn new<T>(program: T) -> Self
    where
        T: AsRef<OsStr>,
    {
        DockerCommand {
            command: Command::new(program),
        }
    }

    fn docker() -> Self {
        Self::new("docker")
    }

    fn docker_compose() -> Self {
        Self::new("docker").args("compose -f docker/local/docker-compose.yaml")
    }

    fn args(mut self, args: &str) -> Self {
        self.command.args(args.split_whitespace());
        self
    }

    fn spawn_wait(mut self) -> Result<()> {
        self.command
            .spawn()
            .context("failed spawning command")?
            .wait()
            .context("failed while waiting")?;
        Ok(())
    }
}
